@@ -1,5 +1,5 @@
 //// File Name: init.c
-//// File Version: 6.002091
+//// File Version: 6.003045
 #include <R.h>
 #include <Rinternals.h>
 #include <stdlib.h> // for NULL
@@ -16,8 +16,15 @@ extern SEXP _CDM_cdm_rcpp_discrimination_index_attribute_patterns(SEXP);
 extern SEXP _CDM_cdm_rcpp_discrimination_index_calc(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_discrimination_index_test_level(SEXP);
 extern SEXP _CDM_cdm_rcpp_discrimination_index_idi(SEXP, SEXP, SEXP);
+extern SEXP _CDM_cdm_rcpp_est_calc_accuracy_version2_consistency_helper(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _CDM_cdm_rcpp_data_prep_long_format(SEXP);
+extern SEXP _CDM_cdm_rcpp_normalize_matrix_row(SEXP);
+extern SEXP _CDM_cdm_rcpp_eval_likelihood_calc_wide_format(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _CDM_cdm_rcpp_eval_likelihood_calc_long_format(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _CDM_cdm_rcpp_eval_likelihood(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_generalized_distance_method(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_ideal_resp_pattern(SEXP, SEXP);
+extern SEXP _CDM_cdm_rcpp_irt_classify_individuals(SEXP);
 extern SEXP _CDM_cdm_rcpp_irt_predict(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_itemfit_sx2_calc_scoredistribution(SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_kli_id(SEXP, SEXP);
@@ -25,6 +32,7 @@ extern SEXP _CDM_cdm_rcpp_mcdina_probs_pcm_groups(SEXP, SEXP, SEXP, SEXP, SEXP,
 extern SEXP _CDM_cdm_rcpp_mcdina_calccounts_pcm_groups(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_modelfit_cor2(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_modelfit_cor_counts(SEXP, SEXP);
+extern SEXP _CDM_cdm_rcpp_sim_model_item_responses(SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_slca_calc_probs(SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_slca_calc_deriv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _CDM_cdm_rcpp_slca_calc_Xdes(SEXP, SEXP);
@@ -41,8 +49,15 @@ static const R_CallMethodDef CallEntries[] = {
     {"_CDM_cdm_rcpp_discrimination_index_calc", (DL_FUNC) &_CDM_cdm_rcpp_discrimination_index_calc, 4},
     {"_CDM_cdm_rcpp_discrimination_index_test_level", (DL_FUNC) &_CDM_cdm_rcpp_discrimination_index_test_level, 1},
     {"_CDM_cdm_rcpp_discrimination_index_idi", (DL_FUNC) &_CDM_cdm_rcpp_discrimination_index_idi, 3},
+    {"_CDM_cdm_rcpp_est_calc_accuracy_version2_consistency_helper", (DL_FUNC) &_CDM_cdm_rcpp_est_calc_accuracy_version2_consistency_helper, 6},
+    {"_CDM_cdm_rcpp_data_prep_long_format", (DL_FUNC) &_CDM_cdm_rcpp_data_prep_long_format, 1},
+    {"_CDM_cdm_rcpp_normalize_matrix_row", (DL_FUNC) &_CDM_cdm_rcpp_normalize_matrix_row, 1},
+    {"_CDM_cdm_rcpp_eval_likelihood_calc_wide_format", (DL_FUNC) &_CDM_cdm_rcpp_eval_likelihood_calc_wide_format, 4},
+    {"_CDM_cdm_rcpp_eval_likelihood_calc_long_format", (DL_FUNC) &_CDM_cdm_rcpp_eval_likelihood_calc_long_format, 4},
+    {"_CDM_cdm_rcpp_eval_likelihood", (DL_FUNC) &_CDM_cdm_rcpp_eval_likelihood, 7},
     {"_CDM_cdm_rcpp_generalized_distance_method", (DL_FUNC) &_CDM_cdm_rcpp_generalized_distance_method, 6},
     {"_CDM_cdm_rcpp_ideal_resp_pattern", (DL_FUNC) &_CDM_cdm_rcpp_ideal_resp_pattern, 2},
+    {"_CDM_cdm_rcpp_irt_classify_individuals", (DL_FUNC) &_CDM_cdm_rcpp_irt_classify_individuals, 1},
     {"_CDM_cdm_rcpp_irt_predict", (DL_FUNC) &_CDM_cdm_rcpp_irt_predict, 4},
     {"_CDM_cdm_rcpp_itemfit_sx2_calc_scoredistribution", (DL_FUNC) &_CDM_cdm_rcpp_itemfit_sx2_calc_scoredistribution, 2},
     {"_CDM_cdm_rcpp_kli_id", (DL_FUNC) &_CDM_cdm_rcpp_kli_id, 2},
@@ -50,6 +65,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"_CDM_cdm_rcpp_mcdina_calccounts_pcm_groups", (DL_FUNC) &_CDM_cdm_rcpp_mcdina_calccounts_pcm_groups, 7},
     {"_CDM_cdm_rcpp_modelfit_cor2", (DL_FUNC) &_CDM_cdm_rcpp_modelfit_cor2, 7},
     {"_CDM_cdm_rcpp_modelfit_cor_counts", (DL_FUNC) &_CDM_cdm_rcpp_modelfit_cor_counts, 2},
+    {"_CDM_cdm_rcpp_sim_model_item_responses", (DL_FUNC) &_CDM_cdm_rcpp_sim_model_item_responses, 3},
     {"_CDM_cdm_rcpp_slca_calc_probs", (DL_FUNC) &_CDM_cdm_rcpp_slca_calc_probs, 3},
     {"_CDM_cdm_rcpp_slca_calc_deriv", (DL_FUNC) &_CDM_cdm_rcpp_slca_calc_deriv, 6},
     {"_CDM_cdm_rcpp_slca_calc_Xdes", (DL_FUNC) &_CDM_cdm_rcpp_slca_calc_Xdes, 2},
